# focus
前提要求：有python3的环境，有git，由于项目不够完善，目前仅支持 Linux和 Mac，仅支持本地，且功能不全
进入到git仓库目录下，然后输入下述命令即可使用，其中focus_path是你放置focus文件包的位置,rep_path是所要管理的仓库所在的位置：
python3 focus_path --repository rep_path &

会在你的.git文件夹下生成一个.focus文件
关注点发生变化后，点击renew即可获取关注点的更新信息